==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkCanvasPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkCanvasPeer

// class file dependencies
// @dep_class 6d147e721e749726 gnu_java_awt_peer_gtk_GtkCanvasPeer
// @dep_class b42ad28212d7bec4 gnu_java_awt_peer_gtk_GtkComponentPeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkComponentPeer

#include "gnu/java/awt/peer/gtk/GtkComponentPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkCanvasPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkCanvasPeer_H_

// Forward structure declarations
struct _jc_java_awt_AWTEvent$object;
struct _jc_java_awt_Canvas$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method$_init$9e00c4cc6f3083bc(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *, struct _jc_java_awt_Canvas$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *);
extern struct _jc_java_awt_Graphics$object *_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method$getGraphics$77f02e8821861132(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *);
extern struct _jc_java_awt_Dimension$object *_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method$handleEvent$db0e2e7973f3405e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *, struct _jc_java_awt_AWTEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method_info$getGraphics$77f02e8821861132;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method_info$getPreferredSize$4730bc91c97b24d9;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method_info$handleEvent$db0e2e7973f3405e;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vmethods {
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *);
	struct _jc_java_awt_Graphics$object	*(*getGraphics$77f02e8821861132)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *);
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *);
	void	(*handleEvent$db0e2e7973f3405e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *, struct _jc_java_awt_AWTEvent$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vmethods	gnu_java_awt_peer_gtk_GtkCanvasPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_refs	gnu_java_awt_peer_gtk_GtkCanvasPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkCanvasPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkCanvasPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkCanvasPeer_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkCanvasPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkCanvasPeer

// class file dependencies
// @dep_class 6d147e721e749726 gnu_java_awt_peer_gtk_GtkCanvasPeer
// @dep_class b42ad28212d7bec4 gnu_java_awt_peer_gtk_GtkComponentPeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkComponentPeer

#include "gnu/java/awt/peer/gtk/GtkComponentPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkCanvasPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkCanvasPeer_H_

// Forward structure declarations
struct _jc_java_awt_AWTEvent$object;
struct _jc_java_awt_Canvas$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method$_init$9e00c4cc6f3083bc(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *, struct _jc_java_awt_Canvas$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Graphics$object *_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method$getGraphics$77f02e8821861132(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method$handleEvent$db0e2e7973f3405e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method_info$getGraphics$77f02e8821861132;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method_info$getPreferredSize$4730bc91c97b24d9;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$method_info$handleEvent$db0e2e7973f3405e;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vmethods {
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Graphics$object	*(*getGraphics$77f02e8821861132)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *) _JC_JCNI_ATTR;
	void	(*handleEvent$db0e2e7973f3405e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vmethods	gnu_java_awt_peer_gtk_GtkCanvasPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_refs	gnu_java_awt_peer_gtk_GtkCanvasPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkCanvasPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkCanvasPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkCanvasPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkCanvasPeer_H_ */
